Index: src/wp-includes/media.php
===================================================================
--- src/wp-includes/media.php	(revision 35702)
+++ src/wp-includes/media.php	(working copy)
@@ -1066,6 +1066,10 @@
 				'url'        => $image_baseurl . $image['file'],
 				'descriptor' => 'w',
 				'value'      => $image['width'],
+				'size'       => array(
+					'width'  => $image['width'],
+					'height' => $image['height'],
+				),
 			);
 		}
 	}
@@ -1079,11 +1083,15 @@
 	 *     One or more arrays of source data to include in the 'srcset'.
 	 *
 	 *     @type type array $width {
 	 *          @type type string $url        The URL of an image source.
 	 *          @type type string $descriptor The descriptor type used in the image candidate string,
 	 *                                        either 'w' or 'x'.
 	 *          @type type int    $value      The source width, if paired with a 'w' descriptor or a
 	 *                                        pixel density value if paired with an 'x' descriptor.
 	 *     }
 	 * }
 	 * @param array  $size_array    Array of width and height values in pixels (in that order).
@@ -1079,11 +1083,15 @@
 	 *
 	 *     @type type array $width {
-	 *          @type type string $url        The URL of an image source.
-	 *          @type type string $descriptor The descriptor type used in the image candidate string,
-	 *                                        either 'w' or 'x'.
-	 *          @type type int    $value      The source width, if paired with a 'w' descriptor or a
-	 *                                        pixel density value if paired with an 'x' descriptor.
+	 *         @type type string $url        The URL of an image source.
+	 *         @type type string $descriptor The descriptor type used in the image candidate string,
+	 *                                       either 'w' or 'x'.
+	 *         @type type int    $value      The source width, if paired with a 'w' descriptor or a
+	 *                                       pixel density value if paired with an 'x' descriptor.
+	 *         @type type array  $sizes {
+	 *             @type int $width  Width of the source image.
+	 *             @type int $height Height of the source image.
+	 *         }
 	 *     }
 	 * }
